@@ -1,12 +1,12 @@
 # SPDX-License-Identifier: Apache-2.0
 import hashlib
-from typing import Any, List, Optional, Union
+from typing import Any, List, Optional, Union, cast
 
 from ruamel import yaml
 from schema_salad.exceptions import ValidationException
 from schema_salad.utils import json_dumps
 
-import cwl_utils.parser.cwl_v1_0 as cwl
+import cwl_utils.parser.cwl_v1_2 as cwl
 from cwl_utils.errors import WorkflowException
 
 
@@ -30,7 +30,17 @@ def convert_stdstreams_to_files(clt: cwl.CommandLineTool) -> None:
                     clt.save(), sort_keys=True).encode('utf-8')).hexdigest())
             out.type = 'File'
             out.outputBinding = cwl.CommandOutputBinding(glob=clt.stderr)
-
+    for inp in clt.inputs:
+        if inp.type == 'stdin':
+            if inp.inputBinding is not None:
+                raise ValidationException(
+                    "Not allowed to specify unputBinding when using stdin shortcut.")
+            if clt.stdin is not None:
+                raise ValidationException(
+                    "Not allowed to specify stdin path when using stdin type shortcut.")
+            else:
+                clt.stdin = '$(inputs.%s.path)' % cast(str, inp.id).rpartition('#')[2].split('/')[-1]
+                inp.type = 'File'
 
 def type_for_source(
     process: Union[cwl.CommandLineTool, cwl.Workflow, cwl.ExpressionTool],
@@ -54,11 +64,11 @@ def param_for_source_id(
     process: Union[cwl.CommandLineTool, cwl.Workflow, cwl.ExpressionTool],
     sourcenames: Union[str, List[str]],
     parent: Optional[cwl.Workflow] = None,
-) -> Union[List[cwl.InputParameter], cwl.InputParameter]:
+) -> Union[List[cwl.WorkflowInputParameter], cwl.WorkflowInputParameter]:
     """Find the process input parameter that matches one of the given sourcenames."""
     if isinstance(sourcenames, str):
         sourcenames = [sourcenames]
-    params: List[cwl.InputParameter] = []
+    params: List[cwl.WorkflowInputParameter] = []
     for sourcename in sourcenames:
         if not isinstance(process, cwl.Workflow):
             for param in process.inputs:
